@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20120731';
+our $VERSION = '0.20120831';
 
-# Table last modified: 2012-07-31
+# Table last modified: 2012-08-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -14,7 +14,7 @@ our %ZIP_TABLE = (
     '005' => '(?:8(?:5(?:[58]5|01|43)|6(?:12|0[12])|798))',
     '006' => '(?:8(?:5(?:[23]0|[58]5|61)|612))',
     '007' => '(?:8(?:5(?:85|0[13578])|632))',
-    '010' => '(?:(?:8(?:5(?:43|6[04]|3[03]|2[025]|8[058]|0[12457]|1[58]|5[08]|7[0247])|6(?:[01]1|22|33|55|68|7[78])|794)|0(?:49[2-4]|[15]95)|1(?:49[2-4]|292)))',
+    '010' => '(?:(?:8(?:5(?:43|6[04]|3[03]|2[025]|8[058]|0[124-7]|1[58]|5[08]|7[0247])|6(?:[01]1|22|33|55|68|7[78])|794)|0(?:49[2-4]|[15]95)|1(?:49[2-4]|292)))',
     '011' => '(?:8(?:5(?:[58]5|01|20|77|1[01])|6(?:05|11|86)))',
     '012' => '(?:8(?:5(?:11|0[12])|6(?:51|0[14])))',
     '013' => '(?:(?:8(?:5(?:92|0[1-4])|6(?:10|0[129]))|0498))',
@@ -42,7 +42,7 @@ our %ZIP_TABLE = (
     '036' => '(?:(?:8(?:5(?:11|22|45|77|0[1-3]|6[0-47]|5[0158]|8[58]|3[038])|6(?:01|42|55|66|8[689])|788)|1(?:59[23]|393|492)|039[26]))',
     '037' => '(?:(?:86(?:55|86)|0392))',
     '038' => '(?:(?:3(?:19[2-6]|39[2-4]|[68]92|595)|85(?:[08]5|60|5[05])|0(?:19[24]|292)|2(?:79[23]|892)|1392))',
-    '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|39[23]|49[23]|79[23]|192|696)|0(?:19[58]|[28]92|595)|11(?:8[015]|9[237])|4(?:29[23]|495|692)|3393))',
+    '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|49[23]|79[23]|[13]92|696)|0(?:19[58]|[28]92|595)|11(?:8[015]|9[237])|4(?:29[23]|495|692)|3393))',
     '040' => '(?:8(?:5(?:77|3[03]|4[13]|5[0-258]|2[02]|8[0158]|0[12]|6[0167]|1[0-2])|6(?:55|4[02]|7[07]|[68][068]|3[12]|0[1-359]|1[016])|7(?:[12][07])))',
     '041' => '(?:(?:8(?:5(?:01|33|40|77|2[23]|8[89]|1[0-25]|6[07]|5[1-8])|6(?:[23]3|48|55|80|1[01])|711)|1(?:19[2-6]|49[6-8]|[36]92)))',
     '042' => '(?:8(?:5(?:[01]1|67|8[58]|5[05])|6(?:39|42|78)))',
@@ -103,14 +103,14 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|22|77|8[0-35]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|3[0-8]|8[457]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[014589]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|1[0-24-689]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:20|55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|3[03]|1[0-3])|7(?:0[127]|1[1267]))|7444))',
-    '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069]|4[0-24589])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|3[0-2568]|7[013]|2[0346]|6[09]|8[048]|4[0278])|0(?:06|60|77)))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[014589]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457]|1[0-24-69])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:20|55|0[1258]|7[07]|8[58]|1[0-2])|3(?:01|22|1[0-3]|3[038])|7(?:0[127]|1[1267]))|7444))',
+    '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
+    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
     '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|3[13489]|6[0168]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[0158]|7[135-8]|8[015-8])|7(?:45|8[027]|5[057]|1[2-6]|0[168]|3[36]|2[1-35])|80[78]|408))',
@@ -130,30 +130,30 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:3[029]|1[15])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-4])|080))',
+    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-4])|080))',
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|8[03]|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|4[0-46-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|4[04]|0[13-578]|8[02-58]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
+    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|0[2-6]|7[0-36]|8[0136-8]|4[0-46-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|5[02578]|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|1[145])|6501))',
-    '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[014]|6[01])))',
+    '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[14]|6[01])))',
     '145' => '(?:85(?:[23]3|01|58|66|1[15]))',
     '146' => '(?:8(?:5(?:[03]1|22|67|8[058]|7[67]|1[0-2]|5[15]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
     '150' => '(?:8(?:5(?:45|3[03]|8[5-7]|2[25]|6[379]|5[05]|7[57]|1[0-24-7]|0[2357-9])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|9[0-2]|5[24589]|7[0-46-8]|0[2-579])|6(?:00|7[1-7])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|7[01378]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
-    '154' => '(?:8(?:5(?:8[0-245]|0[3-6]|4[3-5]|6[05-8]|2[0135]|3[0-369]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
+    '154' => '(?:8(?:5(?:8[0-245]|4[3-5]|6[05-8]|2[0135]|3[0-369]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
     '155' => '(?:86(?:10|26|33|55|6[38]))',
     '156' => '(?:8(?:5(?:22|33|55|8[58]|0[126]|1[01])|666))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
     '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[67]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
     '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:30|1[0-259]|4[379]|8[0-35-9]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:1[015]|3[13]|4[47]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
-    '161' => '(?:8(?:5(?:08|3[19]|6[057]|5[1-46-8]|2[0158]|7[05]|4[015-7]|1[01])|710))',
+    '161' => '(?:8(?:5(?:08|3[19]|6[057]|2[0158]|7[05]|5[236-8]|4[015-7]|1[01])|710))',
     '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:1[25]|4[013]|7[57]|2[279]|5[16-8]|8[0357]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
     '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:7[056]|5[37-9]|6[069])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[013])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|5[35]|6[56])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
-    '164' => '(?:8(?:5(?:[12]2|[67]7|30|8[58]|5[05]|0[13-5]|4[01])|6(?:[25]0|[37]8|66|8[26]|1[17]|4[248])|7(?:01|25)))',
+    '164' => '(?:8(?:5(?:[67]7|12|30|2[25]|8[58]|5[05]|0[13-5]|4[01])|6(?:[037]8|[25]0|66|8[26]|1[17]|4[248])|7(?:01|25)))',
     '165' => '(?:8(?:555|780))',
     '166' => '(?:8(?:5(?:20|55|3[13589]|6[5-7]|4[025]|0[1-36]|8[58]|7[078])|6(?:01|10)))',
     '167' => '(?:8(?:5(?:[24]0|85|7[78]|3[34]|6[07]|0[167]|1[05]|5[15])|6(?:10|28|0[12])|0(?:01|70)))',
@@ -240,7 +240,7 @@ our %ZIP_TABLE = (
     '258' => '(?:(?:85(?:11|85|3[38]|0[168])|0195))',
     '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|39[26])|0(?:19[2-46-8]|39[2356])))',
     '260' => '(?:8(?:6(?:45|5[46]|1[0-3689]|[03][1367]|7[0-357]|8[258]|2[0156]|6[0135-8])|5(?:40|77|2[34]|8[568]|1[0-68]|6[03467]|0[125-9]|3[258]|5[124-79])|7(?:1[0257]|3[03]|2[02]|0[1-37])))',
-    '261' => '(?:8(?:5(?:30|66|75|5[245]|4[45]|1[235]|2[12]|8[126-8]|0[1-378])|6(?:09|86)|733))',
+    '261' => '(?:8(?:5(?:30|66|75|5[245]|4[45]|1[235]|2[0-2]|8[126-8]|0[1-378])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:36|55|0[2-468]|1[0-2])|7(?:10|33)))',
     '263' => '(?:8(?:5(?:[12]2|06|33|77|8[58]|5[05])|733))',
     '264' => '(?:8(?:5(?:[35]0|8[25]|0[15])|6(?:46|51|0[14])|733))',
@@ -253,7 +253,7 @@ our %ZIP_TABLE = (
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
     '275' => '(?:8(?:5(?:[01]1|28|33|60|8[58]|7[25-7])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[34]))',
-    '277' => '(?:8(?:5(?:1[158]|8[124-8]|0[13-57]|7[07]|6[156]|5[0146-8]|3[139]|2[12])|6(?:86|5[45]|6[16])))',
+    '277' => '(?:8(?:5(?:1[158]|0[13-57]|7[07]|6[156]|5[0146-8]|8[125-9]|3[139]|2[12])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:[02]1|10|33|77|5[05])|6(?:01|86)))',
     '279' => '(?:8(?:5(?:30|41|67|5[0358]|2[125-79]|8[58]|1[1689]|0[1-35])|686))',
     '282' => '(?:8610)',
@@ -288,7 +288,7 @@ our %ZIP_TABLE = (
     '312' => '(?:85(?:11|0[1-578]))',
     '313' => '(?:8(?:5(?:[58]5|11)|6(?:[68]6|11)))',
     '314' => '(?:(?:8(?:501|655)|019[2-578]))',
-    '315' => '(?:(?:8(?:5(?:85|2[25]|1[128])|640)|0195))',
+    '315' => '(?:(?:8(?:5(?:85|2[25]|1[1-38])|640)|0195))',
     '316' => '(?:85(?:11|33|0[12]))',
     '317' => '(?:8(?:5(?:11|55)|60[12]))',
     '318' => '(?:85[01]1)',
@@ -419,7 +419,7 @@ our %ZIP_TABLE = (
     '445' => '(?:8(?:5(?:85|1[01]|0[1-35])|60[12]))',
     '446' => '(?:8(?:5(?:40|1[12478]|3[35]|0[1-8]|[58][58]|2[02-6])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
-    '448' => '(?:8(?:6(?:10|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:23|31|50|0[16])|731))',
+    '448' => '(?:8(?:6(?:10|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:31|50|2[35]|0[16])|731))',
     '449' => '(?:029[2-4])',
     '450' => '(?:(?:8(?:5(?:40|3[0238]|6[17]|2[013]|1[05]|7[57]|8[035]|0[125])|6(?:[48]0|01|77|2[06]|1[148]|5[01])|7(?:11|30|65))|6133))',
     '451' => '(?:8(?:5(?:[14]1|85|5[015]|6[0158]|2[0-25]|0[1-38]|7[0157])|6(?:50|88)|701))',
@@ -439,7 +439,7 @@ our %ZIP_TABLE = (
     '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:51|68|70|1[0-2]|2[026])))',
     '466' => '(?:8(?:5(?:40|3[39]|6[057]|2[25]|8[058]|1[0-25]|5[0458]|0[125-8])|6(?:73|6[06]|5[05-7]|3[035])|7(?:11|0[17])))',
     '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|2[0-25]|5[58]|1[01])|6(?:51|86|2[26]|1[015]|0[1-3]|3[039])))',
-    '468' => '(?:8(?:5(?:3[1-46]|2[02]|1[0-4]|8[58]|0[1-7])|626))',
+    '468' => '(?:8(?:5(?:2[02]|1[0-4]|8[58]|0[1-7]|3[1-467])|626))',
     '469' => '(?:879[3467])',
     '470' => '(?:(?:0(?:1(?:88|9[24-68])|29[2-7]|39[2-6]|49[2356]|592)|2(?:19[235-7]|29[26-8]|39[2-48]|49[23])|1(?:19[2-68]|29[2-6])|3(?:29[56]|495)))',
     '471' => '(?:8(?:5(?:7[1-4]|6[056]|3[0-25-7]|0[1-36-8]|8[58]|5[05]|1[0235]|2[1257])|60[1-39]))',
@@ -478,7 +478,7 @@ our %ZIP_TABLE = (
     '506' => '(?:(?:8(?:6(?:66|78|0[13]|8[6-8])|5(?:77|85|0[26]|5[05]))|1(?:49[23568]|19[56]|392)|019[24]|2192))',
     '507' => '(?:8(?:5(?:[16]1|33|2[237])|6(?:50|0[1-3578])|70[1-3568]))',
     '508' => '(?:(?:8(?:5(?:[58]5|11|0[0-2])|6(?:[68]6|11))|0(?:292|494)))',
-    '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|69[235]|19[23]|492)|0(?:29[25-8]|19[278]|393|492)|2(?:59[2358]|29[235])|9(?:29[23568]|19[25])|5(?:19[2358]|292)|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
+    '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|69[235]|19[23]|492)|0(?:29[24578]|19[278]|393|492)|2(?:59[2358]|29[235])|9(?:29[23568]|19[25])|5(?:19[2358]|292)|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
     '510' => '(?:(?:8(?:5(?:[34]0|5[0257]|0[3-6]|2[025]|8[058]|1[0-25]|7[57]|6[0-27])|6(?:[23]1|42|66|70|5[15]|1[56]|0[145]))|0(?:29[2-58]|[13]92)|1292))',
     '511' => '(?:(?:8(?:5(?:[67]7|02|33|5[058]|8[58]|1[01])|6(?:[68]6|01|78)|7(?:11|98))|0(?:29[2-6]|19[28]|59[23]|492)|1192))',
     '512' => '(?:85(?:12|38|50))',
@@ -517,7 +517,7 @@ our %ZIP_TABLE = (
     '545' => '(?:85(?:[01]1|22|33|45|5[05]|8[56]))',
     '546' => '(?:8501)',
     '547' => '(?:85(?:01|80|1[04]))',
-    '549' => '(?:85(?:01|85))',
+    '549' => '(?:8585)',
     '550' => '(?:8(?:5(?:10|38|6[67]|2[27]|8[05]|7[0578]|5[0258]|0[1-35])|6(?:59|60)))',
     '551' => '(?:85[05]1)',
     '552' => '(?:85(?:01|10))',
@@ -527,7 +527,7 @@ our %ZIP_TABLE = (
     '556' => '(?:8(?:5(?:01|85|5[058]|1[0256])|6(?:01|70|6[03-6])))',
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
-    '559' => '(?:8(?:5(?:01|1[019]|5[03589]|8[58]|6[01])|6(?:[01]1|5[18])|729))',
+    '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[12]|6[01])|6(?:[01]1|5[18])|729))',
     '560' => '(?:85(?:79|80|4[38]|5[25]|6[0157]|3[12]|0[56]))',
     '561' => '(?:85(?:[06]1|20|77|5[058]|1[01]))',
     '562' => '(?:8(?:5(?:11|22|43|8[0568]|[05][58]|6[0278])|686))',
@@ -568,7 +568,7 @@ our %ZIP_TABLE = (
     '600' => '(?:8(?:5(?:40|3[03]|1[019]|5[058]|8[1568]|7[07]|6[67]|0[1-35])|6(?:52|77|86|6[56])|7(?:11|87)))',
     '601' => '(?:(?:85(?:01|42|50|3[03]|8[58]|1[01])|0(?:292|797)|1(?:192|495)))',
     '602' => '(?:8(?:5(?:[01]1|[27]0|55|66|8[058])|611))',
-    '603' => '(?:85(?:11|22|55|77))',
+    '603' => '(?:85(?:11|22|55|77|88))',
     '604' => '(?:8(?:5(?:20|8[058]|7[178]|6[07]|5[01568]|1[01]|0[1-358])|666|798))',
     '605' => '(?:8(?:5[01]1|686))',
     '606' => '(?:8(?:5(?:11|22|36|40|[58][58]|0[1257])|792))',
@@ -817,7 +817,7 @@ our %ZIP_TABLE = (
     '858' => '(?:85(?:01|55|8[0589]))',
     '859' => '(?:(?:3(?:79[2378]|29[238]|692)|0(?:49[2578]|19[23])|(?:1[2-5]|6[24])92|4(?:59[5-8]|892)|5(?:39[23]|192)))',
     '860' => '(?:8(?:5(?:4[1357]|3[0149]|7[057]|8[04-8]|6[5-8]|0[1347-9]|5[0-24-8]|2[0-578]|1[0-8])|6(?:55|2[245]|1[1589]|8[168]|0[1-68]|6[08])|7(?:39|9[57])))',
-    '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|4(?:1(?:89|9[235-8])|[34]92|696)|1(?:19[23578]|39[24]|295)|3(?:19[24-6]|29[56]|592)|5(?:49[2-5]|59[28]|292)|2(?:29[235-7]|[14]92)|85(?:01|14|38|2[089])|6[13]95|7292))',
+    '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|4(?:1(?:89|9[2368])|[34]92|696)|1(?:19[23578]|39[24]|295)|3(?:19[24-6]|29[56]|592)|5(?:49[2-5]|59[28]|292)|2(?:29[235-7]|[14]92)|85(?:01|14|38|2[089])|6[13]95|7292))',
     '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[35]|0[139]|1[0-2]|8[08]|5[125])|7(?:20|44|1[06]|9[34]|0[12])|5(?:[127]0|55|0[258])))',
     '863' => '(?:(?:8(?:6(?:31|86)|5[58]5)|2(?:292|895)|1992))',
     '864' => '(?:8(?:6(?:11|86)|501))',
@@ -878,13 +878,13 @@ our %ZIP_TABLE = (
     '921' => '(?:8(?:5(?:5[025]|4[14689]|1[0-2578]|3[0-269]|7[1-9]|2[02-79]|0[15-8]|8[0-47-9]|6[0-2457])|6(?:01|3[079]|1[126]|[25][01])|798))',
     '922' => '(?:(?:8(?:5(?:01|30|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[2-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:5[0-257]|8[0168]|3[013]|2[0158]|0[1-357]|6[067]|7[078]|4[14-6]|1[01])|6(?:50|66|2[06]|1[156]|4[2-46]|8[68]|0[135689]|3[039]))|1(?:29[2-7]|198)|039[238]))',
-    '924' => '(?:8(?:5(?:01|22|33|44|66|77|8[058]|5[58]|1[01])|68[68]))',
+    '924' => '(?:8(?:5(?:01|22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]))',
     '925' => '(?:(?:8(?:5(?:30|85|6[67]|5[05]|0[1-3568]|2[15]|1[01])|6(?:[12]0|09|88))|0(?:19[38]|392|498)))',
     '926' => '(?:(?:8(?:5(?:[013]1|20|66|4[015]|8[568]|5[058])|6(?:[68]6|42|50|1[01]|0[1-359]))|0(?:29[23]|192)))',
     '927' => '(?:(?:0(?:49[235]|29[23]|695)|129[57]|219[23]|8601))',
     '928' => '(?:(?:8(?:5(?:[28]5|41|0[12])|609)|039[235]))',
     '929' => '(?:(?:1(?:39[2-7]|19[23568]|49[2-4]|[6-8]92|29[23])|0(?:49[2-5]|19[238]|29[26]|39[23])|2(?:19[25]|[23]92)))',
-    '930' => '(?:(?:8(?:5(?:0[12457-9]|3[0-25-9]|4[03-58]|[26][0-256]|8[0135-9]|1[0-35-8]|7[078]|5[024-68])|6(?:11|44|5[06]|0[34]|3[67]|6[078]|8[016])|798)|0(?:19[3-68]|39[3-57]|29[238])|1(?:29[258]|392)|2198))',
+    '930' => '(?:(?:8(?:5(?:0[12457-9]|3[0-25-9]|4[03-58]|[26][0-256]|8[0135-9]|1[0-35-8]|7[078]|5[024-68])|6(?:5[06]|0[3-5]|4[24]|3[067]|1[01]|8[016]|6[06-8])|798)|0(?:19[3-68]|39[3-57]|29[238])|1(?:29[258]|392)|2198))',
     '931' => '(?:8(?:5(?:33|62|2[23]|4[03]|7[17]|0[128]|[58][58]|1[0157])|6(?:01|88)))',
     '932' => '(?:(?:8(?:5(?:33|40|75|1[0-258]|5[0158]|6[27]|8[58]|0[1-358]|2[0258])|611)|0(?:39[23568]|19[38]|29[28])))',
     '933' => '(?:(?:8(?:5(?:4[03]|0[1268]|6[367]|8[58]|1[01568]|3[0-3578]|5[08]|2[035-8])|6(?:[28]8|66|0[1-356]|1[01])|7(?:77|88))|0(?:39[235-7]|19[235]|29[235])))',
@@ -931,7 +931,7 @@ our %ZIP_TABLE = (
     '974' => '(?:8(?:577|686))',
     '975' => '(?:8(?:585|686))',
     '976' => '(?:85(?:01|10))',
-    '979' => '(?:(?:2(?:39[2-4]|195|792)|1(?:[135]92|495)|0(?:69[56]|192)))',
+    '979' => '(?:(?:0(?:19[26-8]|69[56])|2(?:39[2-4]|195|792)|1(?:[135]92|495)))',
     '980' => '(?:(?:8(?:4(?:66|5[2-468]|7[78]|8[014-68]|4[023578]|2[0369]|1[0145]|3[013569]|0[1-358])|5(?:1[015]|4[3-6]|8[01358]|5[05]|3[13-5]|6[0156]|7[013-57-9]|0[15]|2[069])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-8]|2[12]|8[56]|7[017])|7(?:0[17]|9[2-578]))|6(?:0(?:55|88)|180)))',
     '981' => '(?:(?:3(?:6(?:8[0-24-68]|9[237])|2(?:9[23568]|8[078])|1(?:9[2-5]|8[089])|49[4-7]|[35]92)|85(?:33|85|6[03]|7[07]|2[235]|5[0-25-8]|1[01]|4[035]|0[125])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|2192))',
     '982' => '(?:8(?:5(?:[03]1|44|66|77|2[13]|8[58]|5[15]|1[01])|601|798))',
